"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const scrollIntoView = require('scroll-into-view');
class Actor {
    constructor(root, options) {
        try {
            this.name = `${root.tagName}-${root.id}-${root.className}`.toLocaleLowerCase();
            this._root = root;
            this._options = options;
            this.isNull = false;
        }
        catch (err) {
            this.isNull = true;
        }
    }
    get root() {
        return this._root;
    }
    get options() {
        return this._options;
    }
    getInformation() {
        if (this.isNull) {
            return {
                borderRadius: {
                    topRight: "50px",
                    topLeft: "50px",
                    bottomRight: "50px",
                    bottomLeft: "50px"
                },
                position: {
                    width: 0,
                    height: 0,
                    x: window.innerWidth / 2,
                    y: window.innerHeight / 2
                }
            };
        }
        const rect = this._root.getBoundingClientRect();
        const style = getComputedStyle(this._root);
        return {
            borderRadius: {
                topLeft: style.borderTopLeftRadius,
                topRight: style.borderTopRightRadius,
                bottomLeft: style.borderBottomLeftRadius,
                bottomRight: style.borderBottomRightRadius
            },
            position: {
                x: rect.x - 2 + window.scrollX,
                y: rect.y + window.scrollY,
                width: rect.width - 2,
                height: rect.height
            }
        };
    }
    _isOutOfViewport() {
        const rect = this._root.getBoundingClientRect();
        // checking if all sides are in
        const out = {
            top: rect.top < 0,
            left: rect.left < 0,
            bottom: rect.bottom > (window.innerHeight || document.documentElement.clientHeight),
            right: rect.right > (window.innerWidth || document.documentElement.clientWidth)
        };
        return out.top || out.left || out.bottom || out.right;
    }
    // https://www.npmjs.com/package/scroll-into-view
    scrollIntoView(options) {
        if (this._isOutOfViewport() || options.centerActorOnFocus) {
            scrollIntoView(this.root, {
                time: options.delay
            });
        }
    }
    toString() {
        return `Actor[${this.name}]`;
    }
}
exports.default = Actor;
