"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OptionBuilder_1 = require("../utils/options/OptionBuilder");
const Environment_1 = require("../utils/Environment");
class Spot {
    constructor(options) {
        this.options = options;
        this.isVisible = false;
        this.spot = document.createElement('div');
        this.spot.classList.add('spot-cell', 'hide-spot');
        document.body.appendChild(this.spot);
        this._applyOptions(this.options);
        this._importCSS();
    }
    _applyOptions(options) {
        OptionBuilder_1.OptionBuilder.checkOptions(options);
        this.spot.style.transitionDuration = `${options.delay}ms`;
    }
    _importCSS() {
        require("../style/spot.css");
        require("../style/sign.css");
    }
    focus(actor) {
        return new Promise((resolve) => {
            // getting options from actor
            let options = Object.assign({}, this.options);
            Object.assign(options, actor.options);
            this._applyOptions(options);
            // triggering callbacks
            options.onFocus(actor, this.focusedActor);
            setTimeout(() => options.onFocused(actor), this.options.delay);
            this.focusedActor = actor;
            this.adaptToActorSize();
            if (this.options.autoScroll && this.isVisible && !actor.isNull) {
                actor.scrollIntoView(this.options);
            }
            setTimeout(() => resolve(), options.delay);
        });
    }
    adaptToActorSize() {
        const dimensions = this.focusedActor.getInformation().position;
        this.spot.style.top = dimensions.y + 'px';
        this.spot.style.height = dimensions.height + 'px';
        this.spot.style.left = dimensions.x + 2 + 'px';
        this.spot.style.width = dimensions.width + 2 + 'px';
        this.spot.style.boxShadow =
            `0px 0px 0px ${Environment_1.Environment.getGreaterWindowDimension()} ${this.options.shadowColor}`;
        if (this.options.matchRadius) {
            const radius = this.focusedActor.getInformation().borderRadius;
            this.spot.style.borderTopLeftRadius = radius.topLeft;
            this.spot.style.borderTopRightRadius = radius.topRight;
            this.spot.style.borderBottomLeftRadius = radius.bottomLeft;
            this.spot.style.borderBottomRightRadius = radius.bottomRight;
        }
    }
    turnOn() {
        this.spot.classList.remove('hide-spot');
        this.isVisible = true;
    }
    turnOff() {
        this.spot.classList.add('hide-spot');
        this.isVisible = false;
    }
}
exports.default = Spot;
